@@ -6,14 +6,12 @@ import os
 import subprocess
 import argparse
 import shutil
-import colorama
 from itunesfslib import converter
 from itunesfslib.helpers import *
 
 
 
 def main():
-    colorama.init()
     parser = argparse.ArgumentParser(
         description='Generates a YAML file or an iTunes Store Transporter package (.itmsp) from a folder\'s assets',
         epilog="Author: Petros Douvantzis @ Evil Window Dod")
